# sdkms/v1.SignAndVerifyApi

All URIs are relative to *https://apps.smartkey.io*

Method | HTTP request | Description
------------- | ------------- | -------------
[**batch_sign**](SignAndVerifyApi.md#batch_sign) | **POST** /crypto/v1/keys/batch/sign | Batch sign with one or more private keys
[**batch_verify**](SignAndVerifyApi.md#batch_verify) | **POST** /crypto/v1/keys/batch/verify | Batch verify with one or more private keys
[**sign**](SignAndVerifyApi.md#sign) | **POST** /crypto/v1/keys/{key-id}/sign | Sign with a private key
[**sign_ex**](SignAndVerifyApi.md#sign_ex) | **POST** /crypto/v1/sign | Sign with a private key
[**verify**](SignAndVerifyApi.md#verify) | **POST** /crypto/v1/keys/{key-id}/verify | Verify a signature with a key
[**verify_ex**](SignAndVerifyApi.md#verify_ex) | **POST** /crypto/v1/verify | Verify a signature with a key


# **batch_sign**
> BatchSignResponse batch_sign(body)

Batch sign with one or more private keys

The data to be signed and the key ids to be used are provided in the request body. The signature is returned in the response body. The ordering of the body matches the ordering of the request. An individual status code is returned for each batch item. Maximum size of the entire batch request is 512 KB. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.SignAndVerifyApi(sdkms/v1.ApiClient(configuration))
body = sdkms/v1.BatchSignRequest() # BatchSignRequest | Batch Sign request

try: 
    # Batch sign with one or more private keys
    api_response = api_instance.batch_sign(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling SignAndVerifyApi->batch_sign: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**BatchSignRequest**](BatchSignRequest.md)| Batch Sign request | 

### Return type

[**BatchSignResponse**](BatchSignResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **batch_verify**
> BatchVerifyResponse batch_verify(body)

Batch verify with one or more private keys

The signature to be verified and the key ids to be used are provided in the request body. The result (true of false) returned in the response body. The ordering of the body matches the ordering of the request. An individual status code is returned for each batch item. Maximum size of the entire batch request is 512 KB. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.SignAndVerifyApi(sdkms/v1.ApiClient(configuration))
body = sdkms/v1.BatchVerifyRequest() # BatchVerifyRequest | Batch Verify request

try: 
    # Batch verify with one or more private keys
    api_response = api_instance.batch_verify(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling SignAndVerifyApi->batch_verify: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**BatchVerifyRequest**](BatchVerifyRequest.md)| Batch Verify request | 

### Return type

[**BatchVerifyResponse**](BatchVerifyResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **sign**
> SignResponse sign(key_id, body)

Sign with a private key

Sign data with a private key. The signing key must be an asymmetric key with the private part present. The sign operation must be enabled for this key. Symmetric keys may not be used to sign data. They can be used with the computeMac and verifyMac methods. <br> The data must be hashed with a SHA-1 or SHA-2 family hash algorithm. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.SignAndVerifyApi(sdkms/v1.ApiClient(configuration))
key_id = 'key_id_example' # str | kid of security object
body = sdkms/v1.SignRequest() # SignRequest | Signature request

try: 
    # Sign with a private key
    api_response = api_instance.sign(key_id, body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling SignAndVerifyApi->sign: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **str**| kid of security object | 
 **body** | [**SignRequest**](SignRequest.md)| Signature request | 

### Return type

[**SignResponse**](SignResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **sign_ex**
> SignResponse sign_ex(body)

Sign with a private key

Sign data with a private key. The signing key must be an asymmetric key with the private part present. The sign operation must be enabled for this key. Symmetric keys may not be used to sign data. They can be used with the computeMac and verifyMac methods. <br> The data must be hashed with a SHA-1 or SHA-2 family hash algorithm. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.SignAndVerifyApi(sdkms/v1.ApiClient(configuration))
body = sdkms/v1.SignRequestEx() # SignRequestEx | Signature request

try: 
    # Sign with a private key
    api_response = api_instance.sign_ex(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling SignAndVerifyApi->sign_ex: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**SignRequestEx**](SignRequestEx.md)| Signature request | 

### Return type

[**SignResponse**](SignResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **verify**
> VerifyResponse verify(key_id, body)

Verify a signature with a key

Verify a signature with a public key. The verifying key must be an asymmetric key with the verify operation enabled. Symmetric keys may not be used to verify data. They can be used with the computeMac and verifyMac operations. <br> The signature must have been created with a SHA-1 or SHA-2 family hash algorithm. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.SignAndVerifyApi(sdkms/v1.ApiClient(configuration))
key_id = 'key_id_example' # str | kid of security object
body = sdkms/v1.VerifyRequest() # VerifyRequest | Verification request

try: 
    # Verify a signature with a key
    api_response = api_instance.verify(key_id, body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling SignAndVerifyApi->verify: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **str**| kid of security object | 
 **body** | [**VerifyRequest**](VerifyRequest.md)| Verification request | 

### Return type

[**VerifyResponse**](VerifyResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **verify_ex**
> VerifyResponse verify_ex(body)

Verify a signature with a key

Verify a signature with a public key. The verifying key must be an asymmetric key with the verify operation enabled. Symmetric keys may not be used to verify data. They can be used with the computeMac and verifyMac operations. <br> The signature must have been created with a SHA-1 or SHA-2 family hash algorithm. 

### Example 
```python
from __future__ import print_function
import time
import sdkms/v1
from sdkms/v1.rest import ApiException
from pprint import pprint

# Configure API key authorization: bearerToken
configuration = sdkms/v1.Configuration()
configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Authorization'] = 'Bearer'

# create an instance of the API class
api_instance = sdkms/v1.SignAndVerifyApi(sdkms/v1.ApiClient(configuration))
body = sdkms/v1.VerifyRequestEx() # VerifyRequestEx | Verification request

try: 
    # Verify a signature with a key
    api_response = api_instance.verify_ex(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling SignAndVerifyApi->verify_ex: %s\n" % e)
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**VerifyRequestEx**](VerifyRequestEx.md)| Verification request | 

### Return type

[**VerifyResponse**](VerifyResponse.md)

### Authorization

[bearerToken](../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

